bluesky
=======

[![Build Status](https://travis-ci.org/bluesky/bluesky.svg)](https://travis-ci.org/bluesky/bluesky)

a Python data collection interface for experimental science

See [documentation](http://bluesky.github.io/bluesky).

[Report an issue with bluesky](https://github.com/bluesky/bluesky/issues/new)

## Conda Recipes

Install the most recent build: `conda install bluesky -c nsls2forge`

Find the tagged recipe [here](https://github.com/nsls-ii-forge/bluesky-feedstock)
